Vivarium Inputs
===============

.. image:: https://badge.fury.io/py/vivarium-inputs.svg
    :target: https://badge.fury.io/py/vivarium-inputs

.. image:: https://github.com/ihmeuw/vivarium_inputs/actions/workflows/build.yml/badge.svg?branch=main
    :target: https://github.com/ihmeuw/vivarium_inputs
    :alt: Latest Version

.. image:: https://readthedocs.org/projects/vivarium_inputs/badge/?version=latest
    :target: https://vivarium_inputs.readthedocs.io/en/latest/?badge=latest
    :alt: Latest Docs


This package is used to transform Global Burden of Disease data and package it into data artifacts
used as inputs into vivarium simulations.

It requires access to the IHME cluster for use (but not for testing).


`Check out the docs! <https://vivarium.readthedocs.io/projects/vivarium-inputs/en/latest/>`_
--------------------------------------------------------------------------------------------
